<?php
/**
 * gproslaw functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package gproslaw
 */

if ( ! function_exists( 'gproslaw_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function gproslaw_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on gproslaw, use a find and replace
		 * to change 'gproslaw' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'gproslaw', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Top Menu', 'gproslaw' ),
            'bottom_menu' => esc_html__( 'Bottom Menu', 'gproslaw' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'gproslaw_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'gproslaw_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gproslaw_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'gproslaw_content_width', 640 );
}
add_action( 'after_setup_theme', 'gproslaw_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function gproslaw_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'gproslaw' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'gproslaw' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'gproslaw_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function gproslaw_scripts() {
	//wp_enqueue_style( 'gproslaw-style', get_stylesheet_uri() );

	wp_enqueue_script( 'gproslaw-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'gproslaw-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'gproslaw_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

// disable for posts
add_filter('use_block_editor_for_post', '__return_false', 10);

// disable for post types
add_filter('use_block_editor_for_post_type', '__return_false', 10);

// breadcrumbs
function breadcrumbs_func() { ob_start();
    if (function_exists('bcn_display') && !is_front_page() && !is_404()) { ?>
        <div class="breadcrumbs-main">
            <div class="container container-2">
                <div class='breadcrumbs' typeof='BreadcrumbList' vocab='http://schema.org/'>
                    <?php bcn_display(); ?>
                </div>
            </div>
        </div>
        <?php
    }
    return ob_get_clean();
}
add_shortcode('breadcrumbs', 'breadcrumbs_func');
// breadcrumbs

// custom permalinks only for practice-area post type
function custom_permalinks_exclude_post_type_fun( $post_type ) {
    if ( $post_type == 'practicearea' || $post_type == 'post' || $post_type == 'page' || $post_type == 'articles' || $post_type == 'attorneys' || $post_type == 'city' ) {
        return '__false';
    }
    return '__true';
}
add_filter( 'custom_permalinks_exclude_post_type', 'custom_permalinks_exclude_post_type_fun');
// custom permalinks only for practice-area post type

// add theme option menu
if( function_exists('acf_add_options_page') ) {
    acf_add_options_page('Theme Options');
}
// add theme option menu

// html tag shortcodes
function figcaption_fun($atts, $content = "") {
    ob_start(); ?>
    <figcaption><?php echo $content; ?></figcaption>
    <?php
    $output = ob_get_clean();
    return $output;
}
add_shortcode('figcaption', 'figcaption_fun');
function figure_fun($atts, $content = "") {
    ob_start(); ?>
    <figure><?php echo $content; ?></figure>
    <?php
    $output = ob_get_clean();
    return $output;
}
add_shortcode('figure', 'figure_fun');

add_shortcode('summary', 'summary_fun');
function summary_fun($atts, $content = "") {
    ob_start(); ?>
    <summary><?php echo $content; ?></summary>
    <?php
    $output = ob_get_clean();
    return $output;
}

function override_mce_options($initArray) {
    $opts = '*[*]';
    $initArray['valid_elements'] = $opts;
    $initArray['extended_valid_elements'] = $opts;
    return $initArray;
}
add_filter('tiny_mce_before_init', 'override_mce_options');

// css js include
function wp_enqueue_scripts_fun() {
    wp_deregister_script('jquery');
    wp_enqueue_script('jquery', get_template_directory_uri().'/js/jquery.min.js', array(),null);
    wp_enqueue_style('Sswald', 'https://fonts.googleapis.com/css?family=Oswald:300,400,500,700|Poppins:300,400,500,700', array(), null);
    wp_enqueue_style('font-awesome', get_template_directory_uri().'/css/font-awesome.min.css', array(), null);
    wp_enqueue_style('bootstrap-css', get_template_directory_uri().'/css/bootstrap.min.css',array(),null);
    
    wp_enqueue_style('carousel-css', get_template_directory_uri().'/css/owl.carousel.css',array(),null);
    
    wp_enqueue_style('style-css', get_template_directory_uri().'/style.css', array(), null);
    wp_enqueue_style('responsive-css', get_template_directory_uri().'/css/responsive.css', array(), null);
    wp_enqueue_style('animate-css', get_template_directory_uri().'/css/animate.min.css', array('bootstrap-css'),null);

    wp_enqueue_script('bootstrap-js', get_template_directory_uri().'/js/bootstrap.min.js', array('jquery'),null,true);
    
    wp_enqueue_script('carousel-js', get_template_directory_uri().'/js/owl.carousel.js', array('jquery'),null,true);
    
    
    
    wp_enqueue_script('wow-js', get_template_directory_uri().'/js/wow.min.js', array('jquery'),null,true);
    wp_register_script('custom-js', get_template_directory_uri().'/js/custom.js', array(),null,true);
    
    wp_localize_script( 'custom-js', 'misha_loadmore_params', array(
		'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php', // WordPress AJAX
		'posts' => json_encode( $wp_query->query_vars ), // everything about your loop is here
		'current_page' => get_query_var( 'paged' ) ? get_query_var('paged') : 1,
		'max_page' => $wp_query->max_num_pages
	) );
    wp_enqueue_script( 'custom-js' );
    // js for canvas graphp
    wp_enqueue_script('canvasjs-min-js', get_template_directory_uri().'/js/canvasjs.min.js', array(),null,true);
    
    
}
add_action('wp_enqueue_scripts', 'wp_enqueue_scripts_fun',11);
//! css js include

// remove script
remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
remove_action( 'wp_print_styles', 'print_emoji_styles' );
remove_action( 'admin_print_styles', 'print_emoji_styles' );
// remove script

//register post type
add_action( 'init', 'codex_register_type_init' );
function codex_register_type_init() {
    $lbl_pa = array(
        'name'               => _x( 'Practice Area', 'post type general name', 'twentyseventeen' ),
        'singular_name'      => _x( 'Practice Area', 'post type singular name', 'twentyseventeen' ),
        'menu_name'          => _x( 'Practice Area', 'admin menu', 'twentyseventeen' ),
        'name_admin_bar'     => _x( 'Practice Area', 'add new on admin bar', 'twentyseventeen' ),
        'add_new'            => _x( 'Add New', 'Practice Area', 'twentyseventeen' ),
        'add_new_item'       => __( 'Add New Practice Area', 'twentyseventeen' ),
        'new_item'           => __( 'New Practice Area', 'twentyseventeen' ),
        'edit_item'          => __( 'Edit Practice Area', 'twentyseventeen' ),
        'view_item'          => __( 'View Practice Area', 'twentyseventeen' ),
        'all_items'          => __( 'All Practice Area', 'twentyseventeen' ),
        'search_items'       => __( 'Search Practice Area', 'twentyseventeen' ),
        'parent_item_colon'  => __( 'Parent Practice Area:', 'twentyseventeen' ),
        'not_found'          => __( 'No Practice Area found.', 'twentyseventeen' ),
        'not_found_in_trash' => __( 'No Practice Area found in Trash.', 'twentyseventeen' )
    );
    $args_pa = array(
        'labels'             => $lbl_pa,
        'description'        => __( 'Description.', 'twentyseventeen' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'practicearea', 'with_front' => false ),
        'capability_type'    => 'post',
        'has_archive'        => false,
        'hierarchical'       => true,
        'menu_position'      => null,
        'menu_icon'          => __( 'dashicons-welcome-learn-more', 'twentyseventeen' ),
        'supports'           => array( 'title', 'editor', 'thumbnail', 'revisions', 'page-attributes' )
    );
    register_post_type( 'practicearea', $args_pa );

    $lbl_ar = array(
        'name'               => _x( 'Articles', 'post type general name', 'twentyseventeen' ),
        'singular_name'      => _x( 'Articles', 'post type singular name', 'twentyseventeen' ),
        'menu_name'          => _x( 'Articles', 'admin menu', 'twentyseventeen' ),
        'name_admin_bar'     => _x( 'Articles', 'add new on admin bar', 'twentyseventeen' ),
        'add_new'            => _x( 'Add New', 'Articles', 'twentyseventeen' ),
        'add_new_item'       => __( 'Add New Articles', 'twentyseventeen' ),
        'new_item'           => __( 'New Articles', 'twentyseventeen' ),
        'edit_item'          => __( 'Edit Articles', 'twentyseventeen' ),
        'view_item'          => __( 'View Articles', 'twentyseventeen' ),
        'all_items'          => __( 'All Articles', 'twentyseventeen' ),
        'search_items'       => __( 'Search Articles', 'twentyseventeen' ),
        'parent_item_colon'  => __( 'Parent Articles:', 'twentyseventeen' ),
        'not_found'          => __( 'No Articles found.', 'twentyseventeen' ),
        'not_found_in_trash' => __( 'No Articles found in Trash.', 'twentyseventeen' )
    );
    $args_ar = array(
        'labels'             => $lbl_ar,
        'description'        => __( 'Description.', 'twentyseventeen' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'articles', 'with_front' => false ),
        'capability_type'    => 'post',
        'has_archive'        => false,
        'hierarchical'       => true,
        'menu_position'      => null,
        'menu_icon'          => __( 'dashicons-welcome-write-blog', 'twentyseventeen' ),
        'supports'           => array( 'title', 'editor', 'thumbnail', 'revisions' )
    );
    register_post_type( 'articles', $args_ar );

    $lbl_at = array(
        'name'               => _x( 'Attorneys', 'post type general name', 'twentyseventeen' ),
        'singular_name'      => _x( 'Attorneys', 'post type singular name', 'twentyseventeen' ),
        'menu_name'          => _x( 'Attorneys', 'admin menu', 'twentyseventeen' ),
        'name_admin_bar'     => _x( 'Attorneys', 'add new on admin bar', 'twentyseventeen' ),
        'add_new'            => _x( 'Add New', 'Attorneys', 'twentyseventeen' ),
        'add_new_item'       => __( 'Add New Attorneys', 'twentyseventeen' ),
        'new_item'           => __( 'New Attorneys', 'twentyseventeen' ),
        'edit_item'          => __( 'Edit Attorneys', 'twentyseventeen' ),
        'view_item'          => __( 'View Attorneys', 'twentyseventeen' ),
        'all_items'          => __( 'All Attorneys', 'twentyseventeen' ),
        'search_items'       => __( 'Search Attorneys', 'twentyseventeen' ),
        'parent_item_colon'  => __( 'Parent Attorneys:', 'twentyseventeen' ),
        'not_found'          => __( 'No Attorneys found.', 'twentyseventeen' ),
        'not_found_in_trash' => __( 'No Attorneys found in Trash.', 'twentyseventeen' )
    );
    $args_at = array(
        'labels'             => $lbl_at,
        'description'        => __( 'Description.', 'twentyseventeen' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'attorneys', 'with_front' => false ),
        'capability_type'    => 'post',
        'has_archive'        => false,
        'hierarchical'       => true,
        'menu_position'      => null,
        'menu_icon'          => __( 'dashicons-groups', 'twentyseventeen' ),
        'supports'           => array( 'title', 'editor', 'thumbnail', 'revisions' ,'page-attributes' )
    );
    register_post_type( 'attorneys', $args_at );
}
//register post type





$lbl_city = array(
    'name'               => _x( 'City', 'post type general name', 'gproslaw' ),
    'singular_name'      => _x( 'City', 'post type singular name', 'gproslaw' ),
    'menu_name'          => _x( 'City', 'admin menu', 'gproslaw' ),
    'name_admin_bar'     => _x( 'City', 'add new on admin bar', 'gproslaw' ),
    'add_new'            => _x( 'Add New', 'City', 'gproslaw' ),
    'add_new_item'       => __( 'Add New City', 'gproslaw' ),
    'new_item'           => __( 'New City', 'gproslaw' ),
    'edit_item'          => __( 'Edit City', 'gproslaw' ),
    'view_item'          => __( 'View City', 'gproslaw' ),
    'all_items'          => __( 'All City', 'gproslaw' ),
    'search_items'       => __( 'Search City', 'gproslaw' ),
    'parent_item_colon'  => __( 'Parent City:', 'gproslaw' ),
    'not_found'          => __( 'No City found.', 'gproslaw' ),
    'not_found_in_trash' => __( 'No City found in Trash.', 'gproslaw' )
);

$args_city = array(
    'labels'             => $lbl_city,
    'description'        => __( 'Description.', 'gproslaw' ),
    'public'             => true,
    'publicly_queryable' => true,
    'show_ui'            => true,
    'show_in_menu'       => true,
    'query_var'          => true,
    'rewrite'            => array( 'slug' => 'city', 'with_front' => false ),
    'capability_type'    => 'post',
    'has_archive'        => false,
    'hierarchical'       => true,
    'menu_position'      => null,
    'supports'           => array( 'title', 'editor', 'thumbnail', 'revisions', 'page-attributes' ),
    'menu_icon'          => __( 'dashicons-store', 'gproslaw' ),
);

register_post_type( 'city', $args_city );

$lbl_cities = array(
    'name'              => _x( 'Cities', 'taxonomy general name', 'gproslaw' ),
    'singular_name'     => _x( 'Cities', 'taxonomy singular name', 'gproslaw' ),
    'search_items'      => __( 'Search Cities', 'gproslaw' ),
    'all_items'         => __( 'All Cities', 'gproslaw' ),
    'parent_item'       => __( 'Parent Cities', 'gproslaw' ),
    'parent_item_colon' => __( 'Parent Cities:', 'gproslaw' ),
    'edit_item'         => __( 'Edit Cities', 'gproslaw' ),
    'update_item'       => __( 'Update Cities', 'gproslaw' ),
    'add_new_item'      => __( 'Add New Cities', 'gproslaw' ),
    'new_item_name'     => __( 'New Cities Name', 'gproslaw' ),
    'menu_name'         => __( 'Cities', 'gproslaw' ),
);

$args_cities = array(
    'public'            => false,
    'hierarchical'      => true,
    'labels'            => $lbl_cities,
    'show_ui'           => true,
    'show_admin_column' => true,
    'query_var'         => true,
    'rewrite'           => array( 'slug' => 'cities' ),
);

register_taxonomy( 'cities', array( 'city' ), $args_cities );

//menu title
function filter_nav_menu_items($menu){
    $post_type = ($menu->object);

    if ($post_type === 'practicearea') {
        $menu_title = get_field('menu_title',$menu->ID) ? ' ('.get_field('menu_title',$menu->ID) . ')' : '' ;
        $menu->post_title = $menu->post_title . $menu_title;
        $menu->title = $menu->title . $menu_title;

    }

    return $menu;
}
add_filter( 'wp_setup_nav_menu_item', 'filter_nav_menu_items', 1 );

class Set_Title_Walker_Nav_Menu extends Walker_Nav_Menu {
    function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
        $classes = empty( $item->classes ) ? array() : (array) $item->classes;
        $classes[] = 'menu-item-' . $item->ID;
        $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
        $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

        $menu_title = get_field('menu_title',$item->object_id) ? get_field('menu_title',$item->object_id) : $item->title ;

        $output .= sprintf( "\n<li %s><a href='%s' title='%s' >%s</a>\n", $class_names, $item->url, $menu_title, $menu_title );
    }
}
//menu title

// thank you redirect
  add_action('wp_footer', 'thank_you_redirect');
  function thank_you_redirect(){ ?>
      <script>
          document.addEventListener('wpcf7mailsent', function(event) {
              if(event.detail.contactFormId == '174') {
                  location = '<?php echo get_permalink( get_page_by_path( 'thank-you-contact-us.shtml' ) );?>';
              }
              else if(event.detail.contactFormId == '808') {
                  location = '<?php echo get_permalink( get_page_by_path( 'thank-you-email.shtml' ) );?>';
              }
              else if(event.detail.contactFormId == '5') {
                  location = '<?php echo get_permalink( get_page_by_path( 'thank-you-footer.shtml' ) );?>';
              }
			  else if(event.detail.contactFormId == '296') {
                  location = '<?php echo get_permalink( get_page_by_path( 'thank-you-popup.shtml' ) );?>';
              }
			  else if(event.detail.contactFormId == '181') {
                  location = '<?php echo get_permalink( get_page_by_path( 'thank-you-review-us.shtml' ) );?>';
              }else if(event.detail.contactFormId == '6227') {
                  location = '<?php echo get_permalink( get_page_by_path( 'thank-you-landing-page.shtml' ) );?>';
              }
			  			  

          }, false);
      </script>
      <?php
  }
// thank you redirect

/*
* Add columns to exhibition post list
*/
function custom_book_column( $column, $post_id ) {
    global $post;

    switch ( $column ) {
        case 'menu_order' :
            echo  $post->menu_order;
            break;
    }
}
function set_custom_edit_book_columns($columns) {
    //unset( $columns['author'] );
    $columns['menu_order'] = __( 'Menu Order', 'your_text_domain' );
    return $columns;
}

function my_movie_sortable_columns( $columns ) {
    $columns['menu_order'] = 'menu_order';
    return $columns;
}

add_action( 'manage_page_posts_custom_column' , 'custom_book_column', 100, 2 );
add_filter( 'manage_page_posts_columns', 'set_custom_edit_book_columns' );
add_filter( 'manage_edit-page_sortable_columns', 'my_movie_sortable_columns' );

// active class
function my_secondary_menu_classes( $classes, $item ) {
    global $post;
    // blog single page
$classes[] =  get_post_type();
    if ( $item->title == 'Blog' && 'post' == get_post_type() && ( is_singular('post') || is_archive() ) ) {
        $classes[] = 'current-menu-item';
    }

    if ( $item->title == 'Articles' && is_singular('articles') ) {
        $classes[] = 'current-menu-item';
    }
    if ( $item->title == 'Practice Areas' && 'practicearea' == is_singular('practicearea') ) {
        $classes[] = 'current-menu-item';
    }
     if ( $item->title == 'Practice Areas' && 'practicearea' == is_singular('city') ) {
        $classes[] = 'current-menu-item';
    }

    /*if ( $item->title == 'Articles' && 'articles' == get_post_type() && ( is_singular('articles') )  ) {
        $classes[] = 'current-menu-item';
    }*/
    //echo '<pre>'; print_r($item); echo '</pre>';
    return $classes;
}
add_filter( 'nav_menu_css_class', 'my_secondary_menu_classes', 10, 2 );
// active class

// Canonical url in amp 
/*function webslaw_theme_modified_canonical_url( $data ) {
	$canonical = '';
	$canonical = ampforwp_generate_canonical();
	if ( !empty($canonical) ) {

		if(substr($canonical, -1) == "/"){ 
			$canonical = $canonical.'amp/';
		}else{
			$canonical = $canonical.'/amp/';
		}

		$data['canonical_url'] = str_replace('//amp','/amp',$canonical);
	}
	return $data;
}*/
//add_filter('amp_post_template_data', 'webslaw_theme_modified_canonical_url', 90);

// Canonical url in amp 

function ShowGraphShortcode() {
	ob_start();
// 	return '<div class="graph-main"><div id="accidentTrends" style="height: 370px; max-width: 920px; margin: 0px auto;"></div></div>';
	
?>
<div class="gp-graph-main">
          <div class="gp-graph-inner">
            <div class="gpg-col">
              <div class="gpg-point">
                <div class="gpg-data"><span>2013 :</span> 11,146</div>
              </div>
            </div>
            <div class="gpg-col">
              <div class="gpg-point">
                <div class="gpg-data"><span>2014 :</span> 10,627</div>
              </div>
            </div>
            <div class="gpg-col">
              <div class="gpg-point">
                <div class="gpg-data"><span>2015 :</span> 11,544</div>
              </div>
            </div>
            <div class="gpg-col">
              <div class="gpg-point">
                <div class="gpg-data"><span>2016 :</span> 12,190</div>
              </div>
            </div>
            <div class="gpg-col">
              <div class="gpg-point">
                <div class="gpg-data"><span>2017 Driver :</span> 11,160</div>
              </div>
            </div>
          </div></div>
<?php
	$output_string = ob_get_contents();
	ob_end_clean();
	return $output_string;
}
add_shortcode('showgraph', 'ShowGraphShortcode');

function ShowRoadSafetyGraphShortcode() {
	ob_start();
?>
	<div class="chart-2">
	<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 367.6 254.6" style="enable-background:new 0 0 367.6 254.6;" xml:space="preserve" width="100%" height="100%">
		<defs>
		  	<style type="text/css">
		    	@import url('https://fonts.googleapis.com/css?family=Poppins:400,600,700');
		 	</style>
		</defs>
		<style>
			.st0{display:none;fill:#EAEAEA;stroke:#373435;stroke-width:6.9449;}
			.st1{fill:#96989A;fill-opacity:0.502;}
			.st2{fill:#373435;}
			.st3, text{font-family:'Poppins, sans-serif';}
			.st4{font-size:7.8556px;}
			.st5{enable-background:new;}
			.st6{font-size:6.5877px;}
			.st7{fill:#1baeff;}
			.st8{fill:#000D42;}
			.st9{fill:#FEFEFE;}
			.st10{font-size:15.7113px;}
			.st11{font-size:6.4088px;}
			.fill2{font-size:8px;}
				@keyframes dash-animation-opposite {
					to {
						stroke-dashoffset: -1000;
					}
				}
				.dash-move-opposite {
					animation: dash-animation-opposite 20s infinite linear;
				}
				.dashed-line {
					stroke-dasharray: 5;
				}
				.v-line-animation .st3 {
					stroke: #000d42;
					stroke-width: 0.1;
				}
				.h-line-animation .st3{
					stroke: #1990d4;
					stroke-width: 0.1;
				}
				.blink{
					fill:#FEFEFE;
					animation: pulse 2.5s infinite;
					-webkit-transform-origin: center center;
					opacity: 1;
					width:30px;
					height:30px;
				}
				@keyframes pulse {
					0% {
					stroke-width: 1;
					stroke: rgba(0, 0, 0, 1);
					}
					100% {
					stroke-width: 10;
					stroke: rgba(0, 0, 0, 0);
					}
				}
		</style>
		<g id="Layer_x0020_1">
			<g id="_250168661296">
				<rect x="210.8" y="89.5" class="st0" width="0.3" height="0.3"/>
				<g class="h-line-animation">
				   	<line class="st3 dashed-line dash-move-opposite" x2="100%" x1="0" y2="30" y1="30"></line>
					<line class="st3 dashed-line dash-move-opposite" x2="100%" x1="0" y2="63" y1="63"></line>
					<line class="st3 dashed-line dash-move-opposite" x2="100%" x1="0" y2="95" y1="95"></line>
					<line class="st3 dashed-line dash-move-opposite" x2="100%" x1="0" y1="125" y2="125"></line>
					<line class="st3 dashed-line dash-move-opposite" x2="100%" x1="0" y1="156" y2="156"></line>
		   		</g>
			   	<g class="v-line-animation">
					<line y1="0" y2="100%" class="st3 dashed-line dash-move-opposite" x2="45" x1="45"></line>
					<line y1="0" y2="100%" class="st3 dashed-line dash-move-opposite" x2="100" x1="100"></line>
					<line y1="0" y2="100%" class="st3 dashed-line dash-move-opposite" x2="155" x1="155"></line>
					<line y1="0" y2="100%" class="st3 dashed-line dash-move-opposite" x2="210" x1="210"></line>
					<line y1="0" y2="100%" class="st3 dashed-line dash-move-opposite" x2="267" x1="267"></line>
					<line y1="0" y2="100%" class="st3 dashed-line dash-move-opposite" x2="325" x1="325"></line>
			   	</g>
				<text transform="matrix(1 0 0 1 27.2998 159.2977)" class="fill2" style="font-family: 'Poppins';font-weight:700;">CONGESTION</text>
				<text transform="matrix(1 0 0 1 85.1045 128.036)" class="fill2" style="font-family: 'Poppins';font-weight:700;">SPEEDING</text>
				<text transform="matrix(1 0 0 1 146.2158 92.0219)" class="st5"><tspan x="0" y="0" class="fill2" style="font-family: 'Poppins';font-weight:700;">ROAD</tspan><tspan x="-10.5" y="9.4" class="fill2" style="font-family: 'Poppins';font-weight:700;">CONDITIONS</tspan></text>
				<text transform="matrix(1 0 0 1 191.8809 60.056)" class="st5"><tspan x="0" y="0" class="fill2" style="font-family: 'Poppins';font-weight:700;">DISTRACTED </tspan><tspan x="7.2" y="9.4" class="fill2" style="font-family: 'Poppins';font-weight:700;">DRIVING</tspan></text>
				<text transform="matrix(1 0 0 1 250.5 -33.3356)" class="fill2" style="font-family: 'Poppins';">	</text>
				<text transform="matrix(1 0 0 1 240.2021 29.2481)" class="st5"><tspan x="0" y="0" class="fill2" style="font-family: 'Poppins';font-weight:700;">GENERAL DISREGARD </tspan><tspan x="4.1" y="7.9" class="fill2" style="font-family: 'Poppins';font-weight:700;">FOR TRAFFIC LAWS</tspan></text>
				<path class="st7" d="M0.2,257.4c0,0,220.1-1.5,367.4-1.5V112.7c-15,4.8-31.6,10.5-42.3,15.7c0,0-114,46.1-138.6,51.6
					c0,0-70.5,23.7-157.8,26L0,207.2L0.2,257.4z"/>
				<g>
					<path fill="url(#skyGradient)" class="st8" d="M41.1,206.9l-41,1.6l0-2.8l40.9-1.5l0,0L41.1,206.9z M367.6,109.6v3.1l-8.6,2.9l-8.7,3.1l-8.8,3.3l-8.8,3.4
						l-8.8,3.5l-8.9,3.6l-9,3.7l-9.1,3.7l-9.2,3.7l-9.3,3.7l-9.4,3.7l-9.4,3.7l-9.6,3.7l-9.7,3.7l-9.8,3.7l-9.9,3.6l-10.1,3.5
						l-10.1,3.5l-10.4,3.3l-10.5,3.2l-10.6,3l-10.8,3l-10.9,2.8l-11.2,2.5l-11.2,2.4l-11.4,2.2l-11.7,2l-11.8,1.7l-12,1.5L66,205.3
						l-12.4,1l-12.6,0.7l-0.2-2.8l12.5-0.7l12.4-1l12.1-1.2l11.9-1.5l11.8-1.7l11.6-2l11.4-2.2l11.2-2.3l11.1-2.6l10.9-2.8l10.7-2.9
						l10.6-3l10.5-3.2l10.3-3.3l10.1-3.4l10-3.6l9.9-3.6l9.8-3.7l9.7-3.7l9.5-3.7l9.4-3.7l9.4-3.7l9.3-3.7l9.2-3.7l9.1-3.7l9-3.7
						l8.9-3.6l8.8-3.5l8.8-3.4l8.8-3.3l8.7-3.2L367.6,109.6z"/>
						<defs>
					        <linearGradient id="skyGradient" x1="100%" y1="100%">
					          <stop offset="0%" stop-color="lightblue" stop-opacity=".5">
					            <animate attributeName="stop-color" values="lightblue;blue;red;red;black;red;red;purple;lightblue" dur="14s" repeatCount="indefinite"></animate>
					          </stop>
					          <stop offset="100%" stop-color="lightblue" stop-opacity=".5">
					            <animate attributeName="stop-color" values="lightblue;orange;purple;purple;black;purple;purple;blue;lightblue" dur="14s" repeatCount="indefinite"></animate>
					            <animate attributeName="offset" values=".95;.80;.60;.40;.20;0;.20;.40;.60;.80;.95" dur="14s" repeatCount="indefinite"></animate>    
					          </stop>
					        </linearGradient>
			      		</defs>
				</g>
				<path class="st9 blink" d="M49.5,204.1c0-2.4-1.9-4.3-4.3-4.3c-2.4,0-4.4,1.9-4.4,4.3c0,2.4,1.9,4.4,4.4,4.4
					C47.5,208.5,49.5,206.6,49.5,204.1z M43.6,204.1c0-0.9,0.6-1.5,1.6-1.5c0.9,0,1.5,0.6,1.5,1.5c0,0.9-0.6,1.6-1.5,1.6
					C44.2,205.7,43.6,205.1,43.6,204.1z"/>
				<path class="st9 blink" d="M104.8,198.3c0-2.4-1.9-4.4-4.3-4.4c-2.4,0-4.4,2-4.4,4.4c0,2.4,1.9,4.4,4.4,4.4
					C102.9,202.7,104.8,200.8,104.8,198.3z M98.9,198.3c0-0.9,0.6-1.6,1.6-1.6c0.9,0,1.5,0.7,1.5,1.6s-0.6,1.6-1.5,1.6
					C99.6,199.9,98.9,199.2,98.9,198.3z"/>
				<path class="st9 blink" d="M159.6,187.4c0-2.4-1.9-4.4-4.4-4.4s-4.4,2-4.4,4.4c0,2.4,1.9,4.4,4.4,4.4S159.6,189.9,159.6,187.4z
					 M153.7,187.4c0-0.9,0.7-1.6,1.6-1.6s1.6,0.7,1.6,1.6s-0.7,1.6-1.6,1.6S153.7,188.3,153.7,187.4z"/>
				<path class="st9 blink" d="M215.4,171c0-2.4-1.9-4.4-4.3-4.4c-2.4,0-4.4,2-4.4,4.4c0,2.4,1.9,4.4,4.4,4.4
					C213.5,175.4,215.4,173.4,215.4,171z M209.5,171c0-0.9,0.7-1.6,1.6-1.6s1.5,0.7,1.5,1.6s-0.6,1.6-1.5,1.6S209.5,171.8,209.5,171z"
					/>
				<path class="st9 blink" d="M272.2,149.9c0-2.4-2-4.4-4.4-4.4c-2.4,0-4.4,1.9-4.4,4.4c0,2.4,1.9,4.3,4.4,4.3
					C270.2,154.3,272.2,152.3,272.2,149.9z M266.2,149.9c0-0.9,0.7-1.6,1.6-1.6c0.9,0,1.6,0.7,1.6,1.6s-0.7,1.6-1.6,1.6
					C266.9,151.5,266.2,150.8,266.2,149.9z"/>
				<text transform="matrix(1 0 0 1 35.2041 227.9598)" class="st9 st3 st10" style="font-family: 'Poppins';font-weight:700;">5%</text>
				<text transform="matrix(1 0 0 1 88.9717 221.6234)" class="st9 st3 st10" style="font-family: 'Poppins';font-weight:700;">8%</text>
				<text transform="matrix(1 0 0 1 140.916 213.1517)" class="st9 st3 st10" style="font-family: 'Poppins';font-weight:700;">15%</text>
				<text transform="matrix(1 0 0 1 195.6357 196.8719)" class="st9 st3 st10" style="font-family: 'Poppins';font-weight:700;">16%</text>
				<text transform="matrix(1 0 0 1 251.5078 176.7518)" class="st9 st3 st10" style="font-family: 'Poppins';font-weight:700;">27%</text>
				<text transform="matrix(1 0 0 1 312.5078 151.7758)" class="st9 st3 st10" style="font-family: 'Poppins';font-weight:700;">32%</text>
				<path class="st9 blink" d="M329.2,127.9c0-2.4-2-4.4-4.4-4.4c-2.4,0-4.4,1.9-4.4,4.4c0,2.4,1.9,4.3,4.4,4.3
					C327.2,132.3,329.2,130.3,329.2,127.9z M323.2,127.9c0-0.9,0.7-1.6,1.6-1.6c0.9,0,1.6,0.7,1.6,1.6c0,0.9-0.7,1.6-1.6,1.6
					C323.9,129.5,323.2,128.8,323.2,127.9z"/>
				<text transform="matrix(1 0 0 1 307.8943 29.2481)" class="st5"><tspan x="0" y="30" class="fill2" style="font-family: 'Poppins';font-weight:700;">AGGRESSIVE </tspan><tspan x="6" y="38" class="fill2" style="font-family: 'Poppins';font-weight:700;">DRIVING</tspan></text>
			</g>
		</g>
	</svg>
	</div>
<?php	
	$output_string = ob_get_contents();
	ob_end_clean();
	return $output_string;
}
add_shortcode('showroadsafetygraph', 'ShowRoadSafetyGraphShortcode');

function misha_loadmore_ajax_handler(){
 
	// prepare our arguments for the query
	$args = json_decode( stripslashes( $_POST['query'] ), true );
	$args['paged'] = $_POST['page'] + 1; // we need next page to be loaded
	$args['post_status'] = 'publish';
 
	// it is always better to use WP_Query but not here
	query_posts( $args );
 
	if( have_posts() ) :
 
		// run the loop
		while( have_posts() ): the_post();
 
			 get_template_part('template-parts/content', get_post_type());
 
 
		endwhile;
 
	endif;
	die; // here we exit the script and even no wp_reset_query() required!
}
add_action('wp_ajax_loadmore', 'misha_loadmore_ajax_handler'); // wp_ajax_{action}
add_action('wp_ajax_nopriv_loadmore', 'misha_loadmore_ajax_handler'); // wp_ajax_nopriv_{action}